@@ -1,4 +1,8 @@
-import { IQuestion, parseCodeCell, parseStepsFromCells } from '@boyuai/jupyter-helper';
+import {
+  IQuestion,
+  parseCodeCell,
+  parseStepsFromCells,
+} from '@boyuai/jupyter-helper';
 import { parseQuestionOptions } from '@boyuai/jupyter-helper/lib/quiz';
 import { getQuizQuestionByUUID, parseQuizQuestions } from './services';
 import { ICell, IJupyter } from './types';
@@ -379,7 +383,7 @@ const syncLesson = async function () {
       userId,
       token,
     };
-    const path = `${apiPrefix}/learn/admin/lessons/${lessonId}/jupyter`;
+    const path = `${apiPrefix}/lessons/${lessonId}/jupyter`;
     fetch(`${path}`, {
       body: JSON.stringify(body),
       headers: {
